import bpy
import urllib.parse
import urllib.request
from ..utils import util
import json

class LOGIN_OT_ScaleRender(bpy.types.Operator):
    bl_idname = "scalrender.login_operator"
    bl_label = "Login to ScaleRender"
    bl_description = "Login to ScaleRender"

    email: bpy.props.StringProperty(name="Email")
    password: bpy.props.StringProperty(name="Password", subtype='PASSWORD')

    @staticmethod
    def store_login_data(context, data, result):
        # Use the module name 'scalerender' to access preferences
        prefs = context.preferences.addons['scalerender'].preferences
        prefs.scalerender_token = result['token']
        prefs.email = data['email']  # Assuming the email is returned in the result

    def execute(self, context):
        url = util.BASE_URL + "/plugInlogIn/"
        data = {
            "email": self.email,
            "password": self.password
        }
        encoded_data = urllib.parse.urlencode(data).encode('utf-8')
        try:
            with urllib.request.urlopen(url, data=encoded_data) as response:
                result = json.loads(response.read().decode('utf-8'))
                if 'error' in result:
                    self.report({"ERROR"}, result['error'])
                    return {"CANCELLED"}
                else:
                    self.store_login_data(context, data, result)
                    self.report({"INFO"}, "Logged in as {}".format(self.email))
                    return {"FINISHED"}
        except urllib.error.HTTPError as e:
            # Check for specific status code
            if e.code in (400, 401):  # Unauthorized
                self.report({"ERROR"}, "Incorrect username or password.")
            else:
                error_message = e.read().decode('utf-8')  # More detailed server response
                self.report({"ERROR"}, error_message)
            return {"CANCELLED"}
        except Exception as e:
            self.report({"ERROR"}, str(e))
            return {"CANCELLED"}

    def invoke(self, context, event):
        wm = context.window_manager
        return wm.invoke_props_dialog(self)

class ScaleRenderPreferences(bpy.types.AddonPreferences):
    # Use the module name 'scalerender' as the bl_idname
    bl_idname = "scalerender"

    scalerender_token: bpy.props.StringProperty(
        name="ScaleRender Token",
        description="Token for ScaleRender authentication"
    )

    email: bpy.props.StringProperty(name="Email")

    def draw(self, context):
        layout = self.layout
        layout.label(text="ScaleRender Plugin Settings")
        layout.prop(self, "email", text="Email")

def menu_func(self, context):
    self.layout.operator(LOGIN_OT_ScaleRender.bl_idname, text="ScaleRender Login")

def register():
    bpy.utils.register_class(LOGIN_OT_ScaleRender)
    bpy.utils.register_class(ScaleRenderPreferences)
    bpy.types.TOPBAR_MT_render.append(menu_func)

def unregister():
    bpy.utils.unregister_class(LOGIN_OT_ScaleRender)
    bpy.utils.unregister_class(ScaleRenderPreferences)
    bpy.types.TOPBAR_MT_render.remove(menu_func)