import bpy

# Property group for ScaleRender settings
class ScaleRenderSettings(bpy.types.PropertyGroup):
    priority: bpy.props.EnumProperty(
        name="Priority",
        items=[
            ('LOW', "Low", "Low priority"),
            ('NORMAL', "Normal", "Normal priority")
        ],
        default='LOW'
    )

    engine: bpy.props.EnumProperty(
        name="Engine",
        items=[
            ('CYCLES_OPTIX', "Cycles (OptiX)", "Use Cycles with OptiX"),
            ('CYCLES_CUDA', "Cycles (Cuda)", "Use Cycles with CUDA"),
            ('EEVEE', "Eevee", "Use Eevee")
        ],
        default='CYCLES_OPTIX'
    )

    max_memory: bpy.props.EnumProperty(
        name="Max Memory Per Machine",
        items=[
            ('13000', "29 GB", "29 GB of memory"),
            ('26000', "42 GB", "42 GB of memory"),
            ('52000', "68 GB", "68 GB of memory"),
            ('104000', "120 GB", "120 GB of memory")
        ],
        default='13000'
    )


# Operator to display settings dialog
class RENDERFARM_OT_ScaleRenderSettings(bpy.types.Operator):
    bl_idname = "scalerender.settings"
    bl_label = "ScaleRender Settings"
    bl_options = {'REGISTER', 'UNDO'}

    def execute(self, context):
        # No immediate action needed, settings are stored in the property group
        return {'FINISHED'}

    def invoke(self, context, event):
        return context.window_manager.invoke_props_dialog(self)

    def draw(self, context):
        layout = self.layout
        scn = context.scene
        layout.prop(scn.scalerender_settings, "priority", text="Priority")
        layout.prop(scn.scalerender_settings, "engine", text="Engine")
        layout.prop(scn.scalerender_settings, "max_memory", text="Max Memory Per Machine")
        layout.label(text="Visit 'https://scalerender.net/pricing/' for details")


# Function to add the settings operator to the render menu
def menu_func(self, context):
    self.layout.operator(RENDERFARM_OT_ScaleRenderSettings.bl_idname, text="ScaleRender Settings")


# Register and unregister functions
def register():
    bpy.utils.register_class(ScaleRenderSettings)
    bpy.utils.register_class(RENDERFARM_OT_ScaleRenderSettings)
    bpy.types.Scene.scalerender_settings = bpy.props.PointerProperty(type=ScaleRenderSettings)
    bpy.types.TOPBAR_MT_render.append(menu_func)


def unregister():
    bpy.utils.unregister_class(ScaleRenderSettings)
    bpy.utils.unregister_class(RENDERFARM_OT_ScaleRenderSettings)
    del bpy.types.Scene.scalerender_settings
    bpy.types.TOPBAR_MT_render.remove(menu_func)